@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -69,7 +69,7 @@ int main(int argc, char * argv[])
         if (testType == 0)
             cout << "\ncase " << testCase << " is not supported\n";
 
-        return -1;
+        return RPP_ERROR_NOT_IMPLEMENTED;
     }
 
     int numChannels, offsetInBytes;
@@ -155,7 +155,8 @@ int main(int argc, char * argv[])
     rppHandle_t handle;
     hipStream_t stream;
     CHECK_RETURN_STATUS(hipStreamCreate(&stream));
-    rppCreateWithStreamAndBatchSize(&handle, stream, batchSize);
+    RppBackend backend = RppBackend::RPP_HIP_BACKEND;
+    rppCreate(&handle, batchSize, 0, stream, backend);
 
     // Run case-wise RPP API and measure time
     int missingFuncFlag = 0;
@@ -394,7 +395,7 @@ int main(int argc, char * argv[])
         if (missingFuncFlag == 1)
         {
             cout << "\nThe functionality doesn't yet exist in RPP\n";
-            return -1;
+            return RPP_ERROR_NOT_IMPLEMENTED;
         }
 
         // Copy output buffer to host
@@ -543,7 +544,7 @@ int main(int argc, char * argv[])
         avgWallTime /= (numRuns * noOfIterations);
         cout << fixed << "\nmax,min,avg wall times in ms/batch = " << maxWallTime << "," << minWallTime << "," << avgWallTime;
     }
-    rppDestroyGPU(handle);
+    rppDestroy(handle, backend);
 
     // Free memory
     free(niftiDataArray);
