@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -69,7 +69,7 @@ int main(int argc, char * argv[])
         if (testType == 0)
             cout << "\ncase " << testCase << " is not supported\n";
 
-        return -1;
+        return RPP_ERROR_NOT_IMPLEMENTED;
     }
 
     int numChannels, offsetInBytes;
@@ -150,7 +150,8 @@ int main(int argc, char * argv[])
     // If numThreads value passed is 0, number of OpenMP threads used by RPP will be set to batch size
     Rpp32u numThreads = 0;
     rppHandle_t handle;
-    rppCreateWithBatchSize(&handle, noOfFiles, numThreads);
+    RppBackend backend = RppBackend::RPP_HOST_BACKEND;
+    rppCreate(&handle, noOfFiles, numThreads, nullptr, backend);
 
     // Run case-wise RPP API and measure time
     int missingFuncFlag = 0;
@@ -376,7 +377,7 @@ int main(int argc, char * argv[])
             if (missingFuncFlag == 1)
             {
                 cout << "\nThe functionality doesn't yet exist in RPP\n";
-                return -1;
+                return RPP_ERROR_NOT_IMPLEMENTED;
             }
         }
 
@@ -525,7 +526,7 @@ int main(int argc, char * argv[])
         cout << fixed << "\nmax,min,avg wall times in ms/batch = " << maxWallTime << "," << minWallTime << "," << avgWallTime;
     }
 
-    rppDestroyHost(handle);
+    rppDestroy(handle, backend);
 
     // Free memory
     free(niftiDataArray);
