@@ -1,7 +1,7 @@
 """
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -67,13 +67,19 @@ imageAugmentationMap = {
     37: ["crop", "HOST", "HIP"],
     38: ["crop_mirror_normalize", "HOST", "HIP"],
     39: ["resize_crop_mirror", "HOST", "HIP"],
+    40: ["erode", "HIP"],
+    41: ["dilate", "HIP"],
+    42: ["hue", "HOST", "HIP"],
+    43: ["saturation", "HOST", "HIP"],
     45: ["color_temperature", "HOST", "HIP"],
     46: ["vignette", "HOST", "HIP"],
     49: ["box_filter", "HIP", "HOST"],
-    54: ["gaussian_filter", "HIP"],
+    51: ["median_filter", "HOST", "HIP"],
+    54: ["gaussian_filter", "HOST", "HIP"],
     61: ["magnitude", "HOST", "HIP"],
     63: ["phase", "HOST", "HIP"],
     65: ["bitwise_and", "HOST", "HIP"],
+    66: ["bitwise_not", "HOST", "HIP"],
     67: ["bitwise_xor", "HOST", "HIP"],
     68: ["bitwise_or", "HOST", "HIP"],
     70: ["copy", "HOST", "HIP"],
@@ -83,14 +89,17 @@ imageAugmentationMap = {
     82: ["ricap", "HOST", "HIP"],
     83: ["gridmask", "HOST", "HIP"],
     84: ["spatter", "HOST", "HIP"],
-    85: ["swap_channels", "HOST", "HIP"],
+    85: ["channel_permute", "HOST", "HIP"],
     86: ["color_to_greyscale", "HOST", "HIP"],
     87: ["tensor_sum", "HOST", "HIP"],
     88: ["tensor_min", "HOST", "HIP"],
     89: ["tensor_max", "HOST", "HIP"],
     90: ["tensor_mean", "HOST", "HIP"],
     91: ["tensor_stddev", "HOST", "HIP"],
-    92: ["slice", "HOST", "HIP"]
+    92: ["slice", "HOST", "HIP"],
+    93: ["jpeg_compression_distortion", "HIP"],
+    94: ["posterize", "HOST", "HIP"],
+    95: ["solarize", "HOST", "HIP"]
 }
 
 audioAugmentationMap = {
@@ -117,25 +126,34 @@ voxelAugmentationMap = {
 miscAugmentationMap  = {
     0: ["transpose","HOST", "HIP"],
     1: ["normalize", "HOST", "HIP"],
-    2: ["log", "HOST", "HIP"]
+    2: ["log", "HOST", "HIP"],
+    3: ["concat","HOST","HIP"],
+    4: ["log1p", "HOST", "HIP"]
 }
 
 ImageAugmentationGroupMap = {
-    "color_augmentations" : [0, 1, 2, 3, 4, 13, 31, 34, 36, 45, 81],
-    "effects_augmentations" : [5, 6, 8, 10, 11, 29, 30, 32, 35, 46, 82, 83, 84],
-    "geometric_augmentations" : [20, 21, 23, 24, 26, 28, 33, 37, 38, 39, 63, 79, 80, 92],
-    "filter_augmentations" : [49, 54],
+    "color_augmentations" : [0, 1, 2, 3, 4, 13, 31, 34, 36, 42, 43, 45, 81],
+    "effects_augmentations" : [5, 6, 8, 10, 11, 29, 30, 32, 35, 46, 82, 83, 84, 94, 95],
+    "geometric_augmentations" : [20, 21, 23, 24, 26, 28, 33, 37, 38, 39, 63, 79, 80, 92, 93],
+    "filter_augmentations" : [49, 51, 54],
+    "morphological_operations" : [40, 41],
     "arithmetic_operations" : [61],
-    "logical_operations" : [65, 67, 68],
+    "logical_operations" : [65, 66, 67, 68],
     "data_exchange_operations" : [70, 85, 86],
     "statistical_operations" : [15, 87, 88, 89, 90, 91]
 }
 
+voxelAugmentationGroupMap = {
+    "arithmetic_operations" : [0, 2, 3, 5],
+    "effects_augmentations" : [6],
+    "geometric_augmentations" : [1, 4]
+}
+
 def get_case_number(map, case):
     # Check if the input is numeric (case number)
     if case.isdigit():
         return str(case)
-    
+
     # Otherwise, treat it as a case name and find the corresponding number
     for caseNum, info in map.items():
         if case.lower() == info[0].lower():
@@ -231,9 +249,9 @@ def case_file_check(CASE_FILE_PATH, TYPE, TENSOR_TYPE_LIST, new_file, d_counter)
         return False
 
  # Generate a directory name based on certain parameters
-def directory_name_generator(qaMode, affinity, layoutType, case, path, func_group_finder):
+def directory_name_generator(qaMode, affinity, layoutType, case, path, groupMap, func_group_finder):
     if qaMode == 0:
-        functionality_group = func_group_finder(int(case))
+        functionality_group = func_group_finder(groupMap, int(case))
         dst_folder_temp = path + "/rpp_" + affinity + "_" + layoutType + "_" + functionality_group
     else:
         dst_folder_temp = path
@@ -241,15 +259,15 @@ def directory_name_generator(qaMode, affinity, layoutType, case, path, func_grou
     return dst_folder_temp
 
 # Process the layout based on the given parameters and generate the directory name and log file layout.
-def process_layout(layout, qaMode, case, dstPath, backend, func_group_finder):
+def process_layout(layout, qaMode, case, dstPath, backend, groupMap, func_group_finder):
     if layout == 0:
-        dstPathTemp = directory_name_generator(qaMode, backend, "pkd3", case, dstPath, func_group_finder)
+        dstPathTemp = directory_name_generator(qaMode, backend, "pkd3", case, dstPath, groupMap, func_group_finder)
         log_file_layout = "pkd3"
     elif layout == 1:
-        dstPathTemp = directory_name_generator(qaMode, backend, "pln3", case, dstPath, func_group_finder)
+        dstPathTemp = directory_name_generator(qaMode, backend, "pln3", case, dstPath, groupMap, func_group_finder)
         log_file_layout = "pln3"
     elif layout == 2:
-        dstPathTemp = directory_name_generator(qaMode, backend, "pln1", case, dstPath, func_group_finder)
+        dstPathTemp = directory_name_generator(qaMode, backend, "pln1", case, dstPath, groupMap, func_group_finder)
         log_file_layout = "pln1"
 
     return dstPathTemp, log_file_layout
@@ -411,8 +429,8 @@ def print_case_list(imageAugmentationMap, backendType, parser):
         sys.exit(0)
 
 # Functionality group finder
-def func_group_finder(case_number):
-    for key, value in ImageAugmentationGroupMap.items():
+def func_group_finder(groupMap, case_number):
+    for key, value in groupMap.items():
         if case_number in value:
             return key
     return "miscellaneous"
