@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2019 - 2024 Advanced Micro Devices, Inc.
+Copyright (c) 2019 - 2025 Advanced Micro Devices, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -68,16 +68,16 @@ std::map<string, std::vector<int>> NonSilentRegionReferenceOutputs =
     {"sample3", {0, 34160}}
 };
 
-// Cutoff values for audio HIP kernels
-std::map<string, double> audioHIPCutOff =
+// Cutoff values for audio kernels listed for HOST backend followed by HIP
+static const std::map<string, std::vector<double>> audioCutOff =
 {
-    {"to_decibels", 1e-6},
-    {"pre_emphasis_filter", 1e-6},
-    {"down_mixing", 1e-6},
-    {"spectrogram", 1e-3},
-    {"slice", 1e-20},
-    {"resample", 1e-6},
-    {"mel_filter_bank", 1e-5}
+    {"to_decibels", {1e-20, 1e-6}},
+    {"pre_emphasis_filter", {1e-20, 1e-6}},
+    {"down_mixing", {1e-20, 1e-6}},
+    {"spectrogram", {1e-20, 1e-3}},
+    {"slice",  {1e-20, 1e-20}},
+    {"resample", {1e-7, 1e-6}},
+    {"mel_filter_bank", {1e-20, 1e-5}}
 };
 
 // sets descriptor dimensions and strides of src/dst
@@ -277,8 +277,15 @@ void verify_output(Rpp32f *dstPtr, RpptDescPtr dstDescPtr, RpptImagePatchPtr dst
         std::cout<<"\nCould not open the reference output. Please check the path specified\n";
         return;
     }
-    double cutoff = (backend == "HOST") ? 1e-20 : audioHIPCutOff[testCase];
 
+    auto mapIterator = audioCutOff.find(testCase);
+    if (mapIterator == audioCutOff.end())
+    {
+        std::cout << "\nError: Test case '" << testCase << "' not found in audioCutOff map.\n";
+        return;
+    }
+    const auto& cutoffVector = mapIterator->second;
+    double cutoff = (backend == "HOST") ? cutoffVector[0] : cutoffVector[1];
     // iterate over all samples in a batch and compare with reference outputs
     for (int batchCount = 0; batchCount < dstDescPtr->n; batchCount++)
     {
